#!/bin/bash
# vim: dict+=/usr/share/beakerlib/dictionary.vim cpt=.,w,b,u,t,i,k
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   runtest.sh of /CoreOS/sandbox/Regression/backup_corrupt
#   Description: What the test does
#   Author: Alois Mahdal <amahdal@redhat.com>
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
#
#   Copyright (c) 2015 Red Hat, Inc.
#
#   This program is free software: you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation, either version 2 of
#   the License, or (at your option) any later version.
#
#   This program is distributed in the hope that it will be
#   useful, but WITHOUT ANY WARRANTY; without even the implied
#   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
#   PURPOSE.  See the GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program. If not, see http://www.gnu.org/licenses/.
#
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

# Include Beaker environment
. /usr/bin/rhts-environment.sh || exit 1
. /usr/share/beakerlib/beakerlib.sh || exit 1

PACKAGE="beakerlib"

enum_cases() {
    echo DEBUG0
    echo DEBUG1
}

setup() {
    rlPhaseStartSetup "setup: $tcname"
        case "$tcname" in
            DEBUG0) DEBUG=0 ;;
            DEBUG1) DEBUG=1 ;;
        esac
        echo content1 > file1
        echo content2 > file2
        echo content3 > file3
        mkdir -p manualbk
        cp -r file1 file2 file3 manualbk
    rlPhaseEnd
}

cleanup() {
    rlPhaseStartCleanup "cleanup: $tcname"
        DEBUG=
        rm -rf file1 file2 file3 manualbk
    rlPhaseEnd
}

rlJournalStart
    rlPhaseStartSetup
        rlImport "distribution/dump"
        rlAssertRpm $PACKAGE
        rlRun "TmpDir=\$(mktemp -d)" 0 "Creating tmp directory"
        rlRun "pushd $TmpDir"
    rlPhaseEnd

    for tcname in $(enum_cases);
    do
        setup $tcname
        rlPhaseStartTest "test: $tcname"
            rlLogInfo "DEBUG='$DEBUG'"
            rlFileBackup --clean file1 file2 file3
            rlFileRestore
            rlRun "diff file1 manualbk/file1"
            rlRun "diff file2 manualbk/file2"
            rlRun "diff file3 manualbk/file3"
        rlPhaseEnd
        distribution_dump__mkphase file1 file2 file3
        cleanup
    done

    rlPhaseStartCleanup
        rlRun "popd"
        rlRun "rm -r $TmpDir" 0 "Removing tmp directory"
    rlPhaseEnd
rlJournalPrintText
rlJournalEnd
